SEAM: systematic explanation of attribution-based mechanisms for regulatory genomics
========================================================================
[![PyPI version](https://badge.fury.io/py/seam-nn.svg)](https://badge.fury.io/py/seam-nn)
[![Downloads](https://static.pepy.tech/badge/seam-nn)](https://pepy.tech/project/seam-nn)

<br/>
<p align="center">
	<img src="./docs/_static/seam_logo_light.png#gh-light-mode-only" width="500" height="500">
</p>
<p align="center">
	<img src="./docs/_static/seam_logo_dark.png#gh-dark-mode-only" width="500" height="500">
</p>
<br/>